@@ -7,10 +7,6 @@ from dominator.entities import (Image, SourceImage, Container, DataVolume, Confi
 from obedient import zookeeper
 
 
-def namespace():
-    return os.environ.get('OBEDIENT_GNS_NAMESPACE', 'yandex')
-
-
 def getbuilder(
         zookeepers,
         ssh_keys=(),
@@ -63,11 +59,8 @@ def getbuilder(
         },
     )
 
-    # Temporary stub (config volume will differ between containers)
-    configvolume = ConfigVolume(dest='/etc/powny', files={
-        'powny.yaml': YamlFile({}),
-        'uwsgi.ini': TemplateFile(TextFile('uwsgi.ini')),
-    })
+    configdest = '/etc/powny'
+    uwsgi_ini_file = TemplateFile(TextFile('uwsgi.ini'))
 
     def stoppable(cmd):
         return 'trap exit TERM; {} & wait'.format(cmd)
@@ -89,11 +82,11 @@ def getbuilder(
             'pip install contextlog elog gns=={}'.format(pownyversion),
         ],
         volumes={
-            'config': configvolume.dest,
+            'config': configdest,
             'rules': rules.dest,
             'logs': pownylogs.dest,
         },
-        command=stoppable('gns $POWNY_MODULE -c {}'.format(configvolume.files['powny.yaml'].fullpath)),
+        command=stoppable('gns $POWNY_MODULE -c /etc/powny/powny.yaml'),
     )
     apiimage = SourceImage(
         name='powny-cpython',
@@ -106,11 +99,11 @@ def getbuilder(
             'pip3 install contextlog elog uwsgi gns=={}'.format(pownyversion),
         ],
         volumes={
-            'config': configvolume.dest,
+            'config': configdest,
             'rules': rules.dest,
             'logs': restapilogs.dest,
         },
-        command=stoppable('uwsgi --ini {}'.format(configvolume.files['uwsgi.ini'].fullpath)),
+        command=stoppable('uwsgi --ini uwsgi.ini'),
     )
 
     gitimage = SourceImage(
@@ -182,7 +175,7 @@ def getbuilder(
         files['powny.yaml'] = YamlFile(config)
 
         _volumes = {
-            'config': ConfigVolume(dest=configvolume.dest, files=files),
+            'config': ConfigVolume(dest=configdest, files=files),
             'logs': logs,
         }
         _volumes.update(volumes)
@@ -216,9 +209,9 @@ def getbuilder(
         @staticmethod
         def restapi(ship, name='api', port=restapi_port):
             config = make_config(ship)
-            return container(ship, name, config, files={'uwsgi.ini': configvolume.files['uwsgi.ini']},
-                             backdoor=None, ports={'http': port}, image=apiimage, logs=restapilogs)
-
+            return container(ship, name, config, files={'uwsgi.ini': uwsgi_ini_file},
+                              backdoor=None, ports={'http': port}, image=apiimage, logs=restapilogs)
+        
         @staticmethod
         def collector(ship):
             config = make_config(ship)
